@@ -1,16 +1,22 @@
-/* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*- 
- * $Id: TableKeeper.java,v 1.13 2004/03/16 15:20:52 metlov Exp $
- *
- * This file is part of the Java Expressions Library (JEL).
- *   For more information about JEL visit :
- *    http://kinetic.ac.donetsk.ua/JEL/
- *
- * (c) 1998 -- 2006 by Konstantin Metlov(metlov@kinetic.ac.donetsk.ua);
- *
- * JEL is Distributed under the terms of GNU General Public License.
- *    This code comes with ABSOLUTELY NO WARRANTY.
- *  For license details see COPYING file in this directory.
- */
+/* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
+*   This file is part of the Java Expressions Library (JEL).
+*   For more information about JEL visit : http://fti.dn.ua/JEL/
+*
+*   Copyright (C) 1998, 1999, 2000, 2001, 2003, 2006, 2007, 2009 Konstantin L. Metlov
+*
+*   This program is free software: you can redistribute it and/or modify
+*   it under the terms of the GNU General Public License as published by
+*   the Free Software Foundation, either version 3 of the License, or
+*   (at your option) any later version.
+*
+*   This program is distributed in the hope that it will be useful,
+*   but WITHOUT ANY WARRANTY; without even the implied warranty of
+*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+*   GNU General Public License for more details.
+*
+*   You should have received a copy of the GNU General Public License
+*   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*/
 
 package gnu.jel;
 
@@ -60,7 +66,7 @@ public class TableWriter {
         };
         tables.put("specialTypes",specialTypesStr);
 
-        Class[] specialTypes=new Class[specialTypesStr.length];
+        Class<?>[] specialTypes=new Class<?>[specialTypesStr.length];
         for (int i=10; i<specialTypesStr.length;i++)
           specialTypes[i]=Class.forName(specialTypesStr[i]);
 
@@ -110,7 +116,7 @@ public class TableWriter {
         };
         tables.put("specialClasses",specialClassesAddStr);
 
-        Class[] specialClasses=new Class[specialTypes.length+
+        Class<?>[] specialClasses=new Class<?>[specialTypes.length+
                                         specialClassesAddStr.length];
         System.arraycopy(specialTypes,0,specialClasses,0,
                          specialTypes.length);
@@ -284,7 +290,14 @@ public class TableWriter {
         //                     PL MI MU DI RE AN OR XO EQ NE LT GE GT LE LS RSS RUS LAN LOR ARR SCAT
         byte[] promotionTypes={ 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 2,  2,  2,  0,  0,  3,   4};
         tables.put("promotionTypes",promotionTypes);
-        
+
+        //                      Z   B   C   S   I   J   F   D
+        byte[] arrayTypeCodes={ 4,  8,  5,  9, 10, 11,  6,  7};
+        tables.put("arrayTypeCodes",arrayTypeCodes);
+
+        //                         Z     B     C     S     I     J     F      D      L
+        int[] arrayStoreCodes={ 0x54, 0x54, 0x55, 0x56, 0x4f, 0x50, 0x51,  0x52,  0x53};
+        tables.put("arrayStoreCodes",arrayStoreCodes);
 
         //  --------- WRITING CODE
         ObjectOutputStream oos=
